Exception: ScrapeUnblocker::Error
- Inherits:
-
StandardError
- Object
- StandardError
- ScrapeUnblocker::Error
- Defined in:
- lib/scrapeunblocker/errors.rb
Overview
Base class for every error raised by this library.
Base class for every error raised by this library.